@@ -33,10 +33,10 @@ class DeployApplicationRequest(RoaRequest):
 
 
 	def get_NasId(self):
-		return self.get_path_params().get('NasId')
+		return self.get_query_params().get('NasId')
 
 	def set_NasId(self,NasId):
-		self.add_path_param('NasId',NasId)
+		self.add_query_param('NasId',NasId)
 
 	def get_WebContainer(self):
 		return self.get_query_params().get('WebContainer')
@@ -62,12 +62,24 @@ class DeployApplicationRequest(RoaRequest):
 	def set_SlsConfigs(self,SlsConfigs):
 		self.add_query_param('SlsConfigs',SlsConfigs)
 
+	def get_OssAkSecret(self):
+		return self.get_body_params().get('OssAkSecret')
+
+	def set_OssAkSecret(self,OssAkSecret):
+		self.add_body_params('OssAkSecret', OssAkSecret)
+
 	def get_CommandArgs(self):
 		return self.get_query_params().get('CommandArgs')
 
 	def set_CommandArgs(self,CommandArgs):
 		self.add_query_param('CommandArgs',CommandArgs)
 
+	def get_AcrAssumeRoleArn(self):
+		return self.get_query_params().get('AcrAssumeRoleArn')
+
+	def set_AcrAssumeRoleArn(self,AcrAssumeRoleArn):
+		self.add_query_param('AcrAssumeRoleArn',AcrAssumeRoleArn)
+
 	def get_Readiness(self):
 		return self.get_query_params().get('Readiness')
 
@@ -81,10 +93,10 @@ class DeployApplicationRequest(RoaRequest):
 		self.add_query_param('Timezone',Timezone)
 
 	def get_MountHost(self):
-		return self.get_path_params().get('MountHost')
+		return self.get_query_params().get('MountHost')
 
 	def set_MountHost(self,MountHost):
-		self.add_path_param('MountHost',MountHost)
+		self.add_query_param('MountHost',MountHost)
 
 	def get_BatchWaitTime(self):
 		return self.get_query_params().get('BatchWaitTime')
@@ -92,6 +104,12 @@ class DeployApplicationRequest(RoaRequest):
 	def set_BatchWaitTime(self,BatchWaitTime):
 		self.add_query_param('BatchWaitTime',BatchWaitTime)
 
+	def get_OssAkId(self):
+		return self.get_body_params().get('OssAkId')
+
+	def set_OssAkId(self,OssAkId):
+		self.add_body_params('OssAkId', OssAkId)
+
 	def get_Liveness(self):
 		return self.get_query_params().get('Liveness')
 
@@ -116,6 +134,12 @@ class DeployApplicationRequest(RoaRequest):
 	def set_PackageVersion(self,PackageVersion):
 		self.add_query_param('PackageVersion',PackageVersion)
 
+	def get_TomcatConfig(self):
+		return self.get_query_params().get('TomcatConfig')
+
+	def set_TomcatConfig(self,TomcatConfig):
+		self.add_query_param('TomcatConfig',TomcatConfig)
+
 	def get_CustomHostAlias(self):
 		return self.get_query_params().get('CustomHostAlias')
 
@@ -158,6 +182,12 @@ class DeployApplicationRequest(RoaRequest):
 	def set_ConfigMapMountDesc(self,ConfigMapMountDesc):
 		self.add_body_params('ConfigMapMountDesc', ConfigMapMountDesc)
 
+	def get_OssMountDescs(self):
+		return self.get_body_params().get('OssMountDescs')
+
+	def set_OssMountDescs(self,OssMountDescs):
+		self.add_body_params('OssMountDescs', OssMountDescs)
+
 	def get_PhpConfig(self):
 		return self.get_body_params().get('PhpConfig')
 
@@ -170,6 +200,12 @@ class DeployApplicationRequest(RoaRequest):
 	def set_PreStop(self,PreStop):
 		self.add_query_param('PreStop',PreStop)
 
+	def get_EnableGreyTagRoute(self):
+		return self.get_query_params().get('EnableGreyTagRoute')
+
+	def set_EnableGreyTagRoute(self,EnableGreyTagRoute):
+		self.add_query_param('EnableGreyTagRoute',EnableGreyTagRoute)
+
 	def get_Command(self):
 		return self.get_query_params().get('Command')
 
@@ -183,10 +219,10 @@ class DeployApplicationRequest(RoaRequest):
 		self.add_query_param('UpdateStrategy',UpdateStrategy)
 
 	def get_MountDesc(self):
-		return self.get_path_params().get('MountDesc')
+		return self.get_query_params().get('MountDesc')
 
 	def set_MountDesc(self,MountDesc):
-		self.add_path_param('MountDesc',MountDesc)
+		self.add_query_param('MountDesc',MountDesc)
 
 	def get_Jdk(self):
 		return self.get_query_params().get('Jdk')
@@ -206,6 +242,12 @@ class DeployApplicationRequest(RoaRequest):
 	def set_ChangeOrderDesc(self,ChangeOrderDesc):
 		self.add_query_param('ChangeOrderDesc',ChangeOrderDesc)
 
+	def get_AcrInstanceId(self):
+		return self.get_body_params().get('AcrInstanceId')
+
+	def set_AcrInstanceId(self,AcrInstanceId):
+		self.add_body_params('AcrInstanceId', AcrInstanceId)
+
 	def get_AppId(self):
 		return self.get_query_params().get('AppId')
 
@@ -218,6 +260,12 @@ class DeployApplicationRequest(RoaRequest):
 	def set_ImageUrl(self,ImageUrl):
 		self.add_query_param('ImageUrl',ImageUrl)
 
+	def get_AutoEnableApplicationScalingRule(self):
+		return self.get_query_params().get('AutoEnableApplicationScalingRule')
+
+	def set_AutoEnableApplicationScalingRule(self,AutoEnableApplicationScalingRule):
+		self.add_query_param('AutoEnableApplicationScalingRule',AutoEnableApplicationScalingRule)
+
 	def get_PhpConfigLocation(self):
 		return self.get_query_params().get('PhpConfigLocation')
 
@@ -228,4 +276,10 @@ class DeployApplicationRequest(RoaRequest):
 		return self.get_query_params().get('PostStart')
 
 	def set_PostStart(self,PostStart):
-		self.add_query_param('PostStart',PostStart)
\ No newline at end of file
+		self.add_query_param('PostStart',PostStart)
+
+	def get_AssociateEip(self):
+		return self.get_body_params().get('AssociateEip')
+
+	def set_AssociateEip(self,AssociateEip):
+		self.add_body_params('AssociateEip', AssociateEip)
\ No newline at end of file
